#ifndef _ELM_CTXPOPUP_INTERNAL_PART_EO_H_
#define _ELM_CTXPOPUP_INTERNAL_PART_EO_H_

#ifndef _ELM_CTXPOPUP_INTERNAL_PART_EO_CLASS_TYPE
#define _ELM_CTXPOPUP_INTERNAL_PART_EO_CLASS_TYPE

typedef Eo Elm_Ctxpopup_Internal_Part;

#endif

#ifndef _ELM_CTXPOPUP_INTERNAL_PART_EO_TYPES
#define _ELM_CTXPOPUP_INTERNAL_PART_EO_TYPES


#endif
/** Elementary contex popup internal part class
 *
 * @ingroup Elm_Ctxpopup_Internal_Part
 */
#define ELM_CTXPOPUP_INTERNAL_PART_CLASS elm_ctxpopup_internal_part_class_get()

EWAPI const Efl_Class *elm_ctxpopup_internal_part_class_get(void);

#endif
